@@ -1,18 +1,21 @@
 #[cfg(feature = "use_async_h1")]
-use async_std::{net::TcpStream,
-    io::{prelude::{ReadExt, WriteExt}}
-};
-#[cfg(feature = "use_hyper")]
-use tokio::{
-    net::{TcpStream},
-    io::{AsyncReadExt, AsyncWriteExt}
+use async_std::{
+    io::prelude::{ReadExt, WriteExt},
+    net::TcpStream,
 };
 use std::io;
+#[cfg(feature = "use_hyper")]
+use tokio::{
+    io::{AsyncReadExt, AsyncWriteExt},
+    net::TcpStream,
+};
 
 pub async fn connect_via_http_prx(
-    host: &str, port: u16,
-    phost: &str, pport: u16) -> io::Result<TcpStream> {
-
+    host: &str,
+    port: u16,
+    phost: &str,
+    pport: u16,
+) -> io::Result<TcpStream> {
     let mut socket = TcpStream::connect((phost, pport)).await?;
     let buf = format!(
         "CONNECT {0}:{1} HTTP/1.1\r\n\
@@ -21,14 +24,15 @@ pub async fn connect_via_http_prx(
          \r\n",
         host,
         port,
-        ""  //TODO Auth
-    ).into_bytes();
+        "" //TODO Auth
+    )
+    .into_bytes();
     socket.write(&buf).await?;
     let mut buffer = [0; 40];
     let r = socket.read(&mut buffer).await?;
 
     let mut read = &buffer[..r];
-    if r > 12{
+    if r > 12 {
         if read.starts_with(b"HTTP/1.1 200") || read.starts_with(b"HTTP/1.0 200") {
             loop {
                 if read.ends_with(b"\r\n\r\n") {
@@ -36,12 +40,15 @@ pub async fn connect_via_http_prx(
                 }
                 // else read more
                 let r = socket.read(&mut buffer).await?;
-                if r==0 {
+                if r == 0 {
                     break;
                 }
                 read = &buffer[..r];
             }
         }
     }
-    Err(io::Error::new(io::ErrorKind::InvalidData, format!("{}",host)))
-}
\ No newline at end of file
+    Err(io::Error::new(
+        io::ErrorKind::InvalidData,
+        format!("{}", host),
+    ))
+}
